@@ -2,15 +2,19 @@ from .base import ThinLens, ThickLens
 from .epl import EPL
 from .external_shear import ExternalShear
 from .pixelated_convergence import PixelatedConvergence
+from .pixelated_potential import PixelatedPotential
 from .nfw import NFW
 from .point import Point
 from .pseudo_jaffe import PseudoJaffe
 from .sie import SIE
 from .sis import SIS
 from .singleplane import SinglePlane
+from .batchedplane import BatchedPlane
 from .mass_sheet import MassSheet
 from .tnfw import TNFW
 from .multiplane import Multiplane
+from .multipole import Multipole
+from .enclosed_mass import EnclosedMass
 
 
 __all__ = [
@@ -19,6 +23,7 @@ __all__ = [
     "EPL",
     "ExternalShear",
     "PixelatedConvergence",
+    "PixelatedPotential",
     "Multiplane",
     "NFW",
     "Point",
@@ -26,6 +31,9 @@ __all__ = [
     "SIE",
     "SIS",
     "SinglePlane",
+    "BatchedPlane",
     "MassSheet",
     "TNFW",
+    "Multipole",
+    "EnclosedMass",
 ]
